SignIn class

Inheritance

Constructors

SignIn({required AuthType authType, bool isResetPasswordEnabled = false, bool isSignUpEnabled = false, bool isGuestEnabled = false, bool useSafeArea = true, List<SocialAuthProviderElement> socialAuthProviders = const [], TextEditingController? emailController, TextEditingController? passwordController, EdgeInsets? contentPadding, void onCreateAccountTap()?, void onSignInTap()?, void onSignInAsGuestTap()?, void onPasswordRecoveryTap()?, TextStyle? eMailLabelStyle, TextStyle? eMailTextStyle, StrutStyle? eMailStrutStyle, dynamic eMailOnChanged(String)?, GestureTapCallback? eMailOnTap, Widget? eMailPrefixIcon, TextStyle? passwordLabelStyle, TextStyle? passwordTextStyle, StrutStyle? passwordStrutStyle, dynamic passwordOnChanged(String)?, GestureTapCallback? passwordOnTap, Widget? passwordPrefixIcon, ButtonStyle? signInButtonStyle, ButtonStyle? signInGuestButtonStyle, Key? key, String screenTitle = 'Sign In', String signInButtonTitle = 'Sign In', String guestSignInButtonTitle = 'Sign in as Guest', String dontHaveAnAccountText = 'Don\'t have an account?', String createAnAccountText = 'Create an account', String? emailHintText, String? passwordHintText, String? passwordRecoveryText})
const

Properties

authType AuthType
Choose here what auth type you would like to use for signing in
final
contentPadding EdgeInsets?
final
createAnAccountText String
final
dontHaveAnAccountText String
final
emailController TextEditingController?
final
emailHintText String?
final
eMailLabelStyle TextStyle?
final
eMailOnChanged → dynamic Function(String)?
final
eMailOnTap GestureTapCallback?
final
eMailPrefixIcon Widget?
final
eMailStrutStyle StrutStyle?
final
eMailTextStyle TextStyle?
final
guestSignInButtonTitle String
final
hashCode int
The hash code for this object.
no setterinherited
isGuestEnabled bool
final
isResetPasswordEnabled bool
final
isSignUpEnabled bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
Here you can use either the package's Logo component, either custom one
final
onCreateAccountTap → void Function()?
final
onPasswordRecoveryTap → void Function()?
final
onSignInAsGuestTap → void Function()?
final
onSignInTap → void Function()?
final
passwordController TextEditingController?
final
passwordHintText String?
final
passwordLabelStyle TextStyle?
final
passwordOnChanged → dynamic Function(String)?
final
passwordOnTap GestureTapCallback?
final
passwordPrefixIcon Widget?
final
passwordRecoveryText String?
final
passwordStrutStyle StrutStyle?
final
passwordTextStyle TextStyle?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenTitle String
final
signInButtonStyle ButtonStyle?
final
signInButtonTitle String
final
signInGuestButtonStyle ButtonStyle?
final
socialAuthProviders List<SocialAuthProviderElement>
final
useSafeArea bool
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildSocialButton(SocialAuthProviderElement social, bool showTitle) Widget
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited